@@ -7,6 +7,7 @@ Created on Jan 4, 2019
 import os
 import getpass
 import sys
+import signal
 # set up our python path
 if "/usr/lib/python3/dist-packages" not in sys.path:
     sys.path.append("/usr/lib/python3/dist-packages")
@@ -18,12 +19,16 @@ from timekpr.common.utils import misc
 # main start
 if __name__ == "__main__":
     # simple self-running check
-    if misc.checkAndSetRunning("%s.%s" % (os.path.splitext(os.path.basename(__file__))[0], getpass.getuser())):
+    if misc.checkAndSetRunning(os.path.splitext(os.path.basename(__file__))[0], getpass.getuser()):
         # get out
         sys.exit(0)
 
     # get our admin client
     _timekprAdminClient = timekprAdminClient()
 
+    # this is needed for admin application to react to ctrl+c gracefully
+    signal.signal(signal.SIGINT, _timekprAdminClient.finishTimekpr)
+    signal.signal(signal.SIGTERM, _timekprAdminClient.finishTimekpr)
+
     # start up timekpr admin client
     _timekprAdminClient.startTimekprAdminClient(*sys.argv)
