@@ -7,13 +7,11 @@ Created on Aug 28, 2018
 import os
 import getpass
 import sys
+import signal
 # set up our python path
 if "/usr/lib/python3/dist-packages" not in sys.path:
     sys.path.append("/usr/lib/python3/dist-packages")
 
-# imports
-import signal
-
 # timekpr imports
 from timekpr.client.interface.dbus.daemon import timekprClient
 from timekpr.common.utils import misc
@@ -21,7 +19,7 @@ from timekpr.common.utils import misc
 # main start
 if __name__ == "__main__":
     # simple self-running check
-    if misc.checkAndSetRunning("%s.%s" % (os.path.splitext(os.path.basename(__file__))[0], getpass.getuser())):
+    if misc.checkAndSetRunning(os.path.splitext(os.path.basename(__file__))[0], getpass.getuser()):
         # get out
         sys.exit(0)
 
