@@ -18,12 +18,8 @@ from timekpr.common.utils import misc
 class timekprUserLoginManager(object):
     """Class enables the connection with login1"""
 
-    def __init__(self, pLog):
+    def __init__(self):
         """Initialize all stuff for login1"""
-        # init logging firstly
-        self._logging = pLog
-        log.setLogging(self._logging)
-
         log.log(cons.TK_LOG_LEVEL_INFO, "start timekpr login1 manager")
 
         # variables
@@ -105,7 +101,7 @@ class timekprUserLoginManager(object):
 
     def getUserList(self, pSilent=False):
         """Go through a list of logged in users"""
-        log.log(cons.TK_LOG_LEVEL_DEBUG, "start getUserList") if not pSilent else True
+        log.log(cons.TK_LOG_LEVEL_EXTRA_DEBUG, "start getUserList") if not pSilent else True
 
         # get user list
         wasConnectionLost, loggedInUsersDBUS = self._listUsers()
@@ -117,7 +113,7 @@ class timekprUserLoginManager(object):
             loggedInUsers[str(rUser[1])] = {cons.TK_CTRL_UID: str(int(rUser[0])), cons.TK_CTRL_UNAME: str(rUser[1]), cons.TK_CTRL_UPATH: str(rUser[2])}
 
         # in case debug
-        if not pSilent and log.isDebug():
+        if not pSilent and log.isDebugEnabled():
             # get all properties
             for key, value in loggedInUsers.items():
                 # optimize logging
@@ -127,7 +123,7 @@ class timekprUserLoginManager(object):
                     uNameLog = "%s, %s: %s" % (uNameLog, keyx, valuex)
                 log.log(cons.TK_LOG_LEVEL_DEBUG, uNameLog)
 
-        log.log(cons.TK_LOG_LEVEL_DEBUG, "finish getUserList") if not pSilent else True
+        log.log(cons.TK_LOG_LEVEL_EXTRA_DEBUG, "finish getUserList") if not pSilent else True
 
         # passing back user tuples
         return wasConnectionLost, loggedInUsers
@@ -289,7 +285,7 @@ class timekprUserLoginManager(object):
 
     def terminateUserSessions(self, pUserName, pUserPath, pTimekprConfig):
         """Terminate user sessions"""
-        log.log(cons.TK_LOG_LEVEL_DEBUG, "start terminateUserSessions")
+        log.log(cons.TK_LOG_LEVEL_EXTRA_DEBUG, "start terminateUserSessions")
         log.log(cons.TK_LOG_LEVEL_DEBUG, "inspecting \"%s\" userpath \"%s\" sessions" % (pUserName, pUserPath))
 
         # get user session list
@@ -301,8 +297,8 @@ class timekprUserLoginManager(object):
 
         # go through all user sessions
         for rUserSession in userSessionList:
-            # if excludeTTY and sessionType not in ("unspecified", "tty"):
-            if rUserSession["type"] in pTimekprConfig.getTimekprSessionsCtrl():
+            # if we support this session type and it is not specifically excluded, only then we kill it
+            if rUserSession["type"] in pTimekprConfig.getTimekprSessionsCtrl() and rUserSession["type"] not in pTimekprConfig.getTimekprSessionsExcl():
                 log.log(cons.TK_LOG_LEVEL_INFO, "(delayed 0.1 sec) killing \"%s\" session %s (%s)" % (pUserName, str(rUserSession["session"][1]), str(rUserSession["type"])))
                 # killing time
                 if cons.TK_DEV_ACTIVE:
@@ -336,9 +332,9 @@ class timekprUserLoginManager(object):
             # dispatch a killer for leftovers
             log.log(cons.TK_LOG_LEVEL_INFO, "dipatching a killer for leftover processes after %i seconds" % (tmo))
             # schedule leftover processes to be killed (it's rather sophisticated killing and checks whether we need to kill gui or terminal processes)
-            GLib.timeout_add_seconds(tmo, misc.killLeftoverUserProcesses, self._logging, pUserName, pTimekprConfig.getTimekprSessionsCtrl())
+            GLib.timeout_add_seconds(tmo, misc.killLeftoverUserProcesses, pUserName, pTimekprConfig)
 
-        log.log(cons.TK_LOG_LEVEL_DEBUG, "finish terminateUserSessions")
+        log.log(cons.TK_LOG_LEVEL_EXTRA_DEBUG, "finish terminateUserSessions")
 
     def suspendComputer(self, pUserName):
         """Suspend computer"""
